@@ -25,10 +25,11 @@ from PIL import Image
 
 from sklearn.utils import shuffle
 from sklearn.model_selection import train_test_split
-from sklearn.model_selection import GridSearchCV
+from sklearn.preprocessing import OneHotEncoder
 from sklearn.utils import class_weight
 from sklearn.metrics import confusion_matrix, roc_curve, roc_auc_score, auc
 
+import scipy
 
 class transfer_learner():
 
@@ -55,18 +56,62 @@ class transfer_learner():
 
         if PKL_PATH:
             with open(PKL_PATH, 'rb') as f:
-                dict = pickle.load(f)
+                dic = pickle.load(f)
+
+            if 'X_train' in dic and 'X_val' in dic and 'y_train' in dic and 'y_val' in dic:
+                
+                self.X_train = dic['X_train']
+                self.X_val = dic['X_val']
+                self.y_train = dic['y_train']
+                self.y_val = dic['y_val']
+
+            elif 'X' in dic and 'y' in dic:
+
+                X = dic['X']
+                y = dic['y']
+
+                if len(y.shape) <= 1:
+                    y_onehot = OneHotEncoder().fit_transform(y.reshape(-1, 1))
+                else:
+                    y_onehot = y # already one-hot encoded
+
+                #Shuffle the dataset
+                X_shuffled, y_shuffled = shuffle(X,y_onehot)
+                # Split the dataset
+                X_train, X_test, y_train, y_test = train_test_split(X_shuffled, y_shuffled, test_size=0.1)
+
+                # Split the dataset
+                X_train, X_val, y_train, y_val = train_test_split(X_train, y_train, test_size=0.2)
+
+                if isinstance(X_train,scipy.sparse.csr.csr_matrix):
+                    X_train = X_train.todense()
+                self.X_train = X_train
+
+                if isinstance(X_val,scipy.sparse.csr.csr_matrix):
+                    X_val = X_val.todense()
+                self.X_val = X_val
+
+                if isinstance(y_train,scipy.sparse.csr.csr_matrix):
+                    y_train = y_train.todense()
+                self.y_train = y_train
+
+                if isinstance(y_val,scipy.sparse.csr.csr_matrix):
+                    y_val = y_val.todense()
+                self.y_val = y_val
+
+                if isinstance(X_test,scipy.sparse.csr.csr_matrix):
+                    X_test = X_test.todense()
+                self.X_test = X_test
+
+                if isinstance(y_test,scipy.sparse.csr.csr_matrix):
+                    y_test = y_test.todense()
+                self.y_test = y_test
             
-            self.X_train = dict['X_train']
-            self.X_val = dict['X_val']
-            self.y_train = dict['y_train']
-            self.y_val = dict['y_val']
-            
-            self.num_classes = dict['num_classes']
+            self.num_classes = dic['num_classes']
 
             # labels and class_names are the same.
-            self.labels = dict['class_names']
-            self.class_names = dict['class_names']
+            self.labels = dic['class_names']
+            self.class_names = dic['class_names']
 
         else:
             print("Unable to locate the pkl file: ", PKL_PATH) 
@@ -134,20 +179,19 @@ class transfer_learner():
 
         if PKL_PATH:
             # PKL_PATH = '../data/fundus/C5/C5_202108.pkl' # '../data/fundus/C5/C5_202108.pkl' # the unmasked imgs
-            dict = {}
+            dic = {}
 
-            dict['X_train'] = np.array(self.X_train, dtype=np.int8)
-            dict['X_val'] = np.array(self.X_val, dtype=np.int8)
-            dict['y_train'] = np.array(self.y_train, dtype=np.int8)
-            dict['y_val'] = np.array(self.y_val, dtype=np.int8)
+            dic['X_train'] = np.array(self.X_train, dtype=np.int8)
+            dic['X_val'] = np.array(self.X_val, dtype=np.int8)
+            dic['y_train'] = np.array(self.y_train, dtype=np.int8)
+            dic['y_val'] = np.array(self.y_val, dtype=np.int8)
+            
+            dic['num_classes'] = self.num_classes
+            dic['labels'] = self.labels
+            dic['class_names'] = self.class_names            
             
-            dict['num_classes'] = self.num_classes
-            dict['labels'] = self.labels
-            dict['class_names'] = self.class_names            
-
-            import pickle
             with open(PKL_PATH, 'wb') as f:
-                pickle.dump(dict, f)
+                pickle.dump(dic, f)
 
             print("pickled in ", PKL_PATH)
 
